# insights-ccx-messaging

[![GitHub Pages](https://img.shields.io/badge/%20-GitHub%20Pages-informational)](https://redhatinsights.github.io/insights-ccx-messaging/)
[![codecov](https://codecov.io/gh/RedHatInsights/insights-ccx-messaging/branch/main/graph/badge.svg?token=G00EQ808EP)](https://codecov.io/gh/RedHatInsights/insights-ccx-messaging)
[![License](https://img.shields.io/badge/license-Apache-blue)](https://github.com/RedHatInsights/insights-ccx-messaging/blob/main/LICENSE)

Stub for all CCX services based on Insights Core Messaging framework

<!-- vim-markdown-toc GFM -->

* [Makefile targets](#makefile-targets)

<!-- vim-markdown-toc -->

## Makefile targets

```
Available targets are:

unit_tests           Run unit tests
coverage             Run unit tests, display code coverage on terminal
coverage-report      Run unit tests, generate code coverage as a HTML report
documentation        Generate documentation for all sources
shellcheck           Run shellcheck
pyformat             Reformat all Python sources
help                 Show this help screen
```
